%  
%   HT1D_FEM3.M  Space-Time Heat Transfer Problem in 1-D Wall (FEMLAB)
%       (Example 10.3 and 11.3 in Lecture Notes:  Time Dependent Right BC)
%                                                                               
%   FEMLAB was used to solve the following problem:
%     ut(x,t) = alf*uxx(x,t)   with u(0,t) = uL   u(L,t) = g(t)   u(x,0) = f(x) 
%   where
%     u(L,t) = g(t) = uR*exp(-mu*t)    --- decaying temperature on right side
%     u(0,t) = uL                      --- fixed temp on left   
%     u(x,0) = f(x) = (uR-uL)x/L + uL  --- linear profile 
%
%   This problem models a large wall of thickness L that has a linear temperature
%   profile initially.  At t = 0, the right endpoint temperature starts to decrease
%   exponentially with time.  The object of the simulation is to compute and 
%   visualize the space-time temperature profile within the bar.
%
%   This problem was set up and solved from within the FEMLAB graphical user 
%   interface.  The desired temperature profiles were obtained using FEMLAB's GUI.
%   This was acceptable for the current example -- thus, no further processing is 
%   really necessary here.
%
%   However, it is often necessary to do significant post processing of the basic
%   solution from FEMLAB, so this m-file will demonstrate the basic process (if it 
%   should be needed). The key FEMLAB function of interest here is the "postinterp"
%   command, which extracts the actual FEM solution and interpolates it onto
%   a user-defined grid for plotting and subsequent analysis.  Here, since the
%   problem is 1-D, this step is pretty simple.  And, since all we want to do
%   is plot the solution, the overall program is extremely simple -- but still
%   instructive...
%
%   Note that before running this file, your must "Export the FEMLAB structure 
%   (fem) to the Matlab workspace".  This is done under the File menu in FEMLAB.
%   Also, of course, you must be running with the "FEMLAB with Matlab" interface
%   available.
%
%   File prepared by J. R. White, UMass-Lowell (Dec. 2004)
%

%
%   getting started 
%   (do not do a "clear all" here, since that would delete the fem structure)
      close all, nfig = 0;
%
%   problem data  (for documentation purposes -- only L is used)                                                              
      alf = .0001;     % m^2/s  thermal diffusivity                            
      ul = 100;        % C      left (fixed) temp of bar                        
      ur = 400;        % C      initial temp on right                           
      L = 1;           % m      length of bar 
      mu = .001;       % 1/s    for slow decay   
      mu = .005;       % 1/s    for fast decay   
%
%   get the times where the solution was saved from the fem structure
      tp = fem.sol.tlist;   Ne = length(tp);
%
%   interpolate the temperature profiles on a regular grid from the fem structure
%   for all time points
      Nx = 101;  xp = linspace(0,L,Nx);            % spatial points
      up = postinterp(fem,'T',xp,'solnum',1:Ne);   % up = temps for plotting
      up = up';   % transpose so the matrix looks like before (Nx rows, Ne cols)

%
%   now we have the desired space-time soln (use same plotting technique as before)
%

%   set color and marker code for creating plots
      Ncm = 6;  scm = ['r-';'g:';'b-';'m:';'c-';'k:']; 
%
%   plot curves of up for various times
      st = zeros(Ne,9);
      nfig = nfig+1;   figure(nfig)   
      jj = 0;                     
      for j = 1:Ne
        jj = jj+1;  if jj > 6, jj = 1; end
        plot(xp,up(:,j),scm(jj,:),'LineWidth',2); hold on 
        st(j,:) = sprintf('%5.0f sec',tp(j));
      end
      hold off                          
      title('HT1D\_FEM3:  Bar Temperature Profile with u_R(t) = decaying exponential')
      grid,xlabel('Distance (m)'),ylabel('Temperature (C)')       
      legend(char(st))
%
%   end of problem